@@ -31,7 +31,7 @@ class PushNotificationManager:
                 else:
                     user = User.objects.get(id=uid)
             include_player_ids = user.fcmToken
-            if len(include_player_ids) > 0:
+            if bool(include_player_ids):
                 notification_body = {
                     'contents': {'en': msg},
                     'data': data,
@@ -47,3 +47,5 @@ class PushNotificationManager:
         except OneSignalHTTPError as e:  # An exception is raised if
             # response.status_code != 2xx
             log_exception("PushNotificationManager", e)
+        except Exception as e:
+            log_exception("PushNotificationManager", e)
