@@ -10,6 +10,9 @@ class WorkOrderService(BaseModelAbstract, models.Model):
     class Meta:
         db_table = 'WorkOrderServices'
 
+    def __str__(self):
+        return self.name
+
 
 class WorkOrderServiceCategory(BaseModelAbstract, models.Model):
     service = models.ForeignKey(
